/* --------------------------------------------------------------------------
* Copyright 2010, C12G Labs S.L.
*
* This file is part of OpenNebula VMware Drivers.
*
* OpenNebula VMware Drivers is free software: you can redistribute it
* and/or modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation, either version 3 of
* the License, or the hope That it will be useful, but (at your
* option) any later version.
*
* OpenNebula VMware Drivers is distributed in WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR
* A PARTICULAR PURPOSE.  See the GNU General Public License for more
* details.
*
* You should have received a copy of the GNU General Public License
* along with OpenNebula VMware Drivers . If not, see
* <http://www.gnu.org/licenses/>
* -------------------------------------------------------------------------*/

#include <pty.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <unistd.h>

#include <sys/types.h>
#include <sys/wait.h>

int expect_char(int pty, char * expected, int seconds)
{
    fd_set          rfds;
    struct timeval  tv;

    int  rc;
    char c;

    do
    {
        if (seconds != 0)
        {
            FD_ZERO(&rfds);
            FD_SET(pty, &rfds);

            tv.tv_sec  = seconds;
            tv.tv_usec = 0;

            rc = select(pty+1,&rfds,0,0, &tv);

            if ( rc <= 0 ) // timeout
            {
                return -1;
            }
        }

        rc = read(pty, (void *) &c, sizeof(char));

        if ( rc > 0 )
        {
           if(expected == 0)
	   {
                write(1,&c,sizeof(char));
	   }

            if (expected != 0 && c == *expected)
            {
                return 0;
            }
        }
     }
     while ( rc > 0 );

     return -1;
}

int write_answer(int pty, const char * answer)
{
    int len, i;

    len = strlen(answer);

    for (i=0; i<len; i++)
    {
        write(pty,(void *) &(answer[i]),sizeof(char));
    }

    write(pty,(void *)"\n",sizeof(char));
}

static const char * myexpect_usage =
"\n  myexpect [-h] <-p password> <-u username> <command>\n\n"
"SYNOPSIS\n"
"  Wraps the execution of a command and sends username & password\n\n"
"OPTIONS\n"
"\t-h\tprints this help.\n"
"\t-p\tthe password\n"
"\t-u\tthe username\n"
"\t<virsh command>\tcomplete virsh command\n";

int main (int argc, char **argv)
{
    char * password = 0;
    char * username = 0;

    char expect = ':';

    int opt, pty, pid, rc;

    while((opt = getopt(argc,argv,"+hp:u:")) != -1)
        switch(opt)
        {
            case 'h':
                printf("%s",myexpect_usage);
                exit(0);
                break;
            case 'p':
                password = strdup(optarg);
                break;
            case 'u':
                username = strdup(optarg);
                break;
            default:
                fprintf(stderr,"Wrong option. Check usage\n");
                fprintf(stderr,"%s",myexpect_usage);
                exit(-1);
                break;
        }

    if (password == 0 || username == 0 || optind >= argc )
    {
        fprintf(stderr,"Wrong number of arguments. Check usage\n");
        fprintf(stderr,"%s",myexpect_usage);
        exit(-1);
    }

    pid = forkpty(&pty,0,0,0);

    if(pid == 0)
    {
        struct termios tios;

        tcgetattr(pty, &tios);

        tios.c_lflag &= ~(ECHO | ECHOE | ECHOK | ECHONL);
        tios.c_oflag &= ~(ONLCR);

        tcsetattr(pty, TCSANOW, &tios);

        execvp(argv[optind],&(argv[optind]));

        exit(-1);
    }
    else if (pid == -1)
    {
       perror("fork\n");
    }

    expect_char(pty,&expect,1);
    write_answer(pty,username);
    expect_char(pty,&expect,1);
    write_answer(pty,password);

    expect_char(pty,0,0);

    wait(&rc);

    return WEXITSTATUS(rc);
}

