require ENV['ONE_SIMLOCATION']+'/lib/test_lib'

describe "Stop/Resume/Shutdown Integration tests" do
    before(:all) do
         @fixed_template = {:name => "fixednetwork",
                            :type => "FIXED",
                            :bridge => "VM Network",
                            :leases => [{:ip => "192.168.1.112"},
                                        {:ip => "192.168.1.113"}]
                            }


        fixed_text = TemplateParser::template_like_str(@fixed_template, true)
        @fixed_net = VirtualNetworkTest.new({:template_text => fixed_text})
        @fixed_net.create.should eql(nil)
        @fixed_net.info.should eql(nil)
        
        @vm_template = {
            :nic => {
                :network => @fixed_template[:name]
            }
        }
        
        @vm = VirtualMachineTest.new({:template => @vm_template})
        
        @host = HostTest.new
        @host.create.should eql(nil)
        @host.info.should eql(nil)
        
        @vm.submit.should eql(nil)
        
        host_id = @host.get_id
        @vm.deploy(host_id).should eql(nil)

        @vm.check_state("runn", 80).should eql(true)
        @vm.check_active(100).should eql(true)
    end
    
    it "should stop a VirtualMachine and check for the stopped VM" do
        @vm.stop.should eql(nil)
        
        @vm.check_state("stop", 80).should eql(true)
        
        vmid = @vm.get_id

        @vm.get_reason.should eql(2) # Stop/Resume
        @vm.get_stime.should > 0
        @vm.get_etime.should >= @vm.get_stime
        @vm.get_pstime.should_not eql(0)
        @vm.get_petime.should >= @vm.get_pstime
        @vm.get_rstime.should_not eql(0)
        @vm.get_retime.should >= @vm.get_rstime
        @vm.get_estime.should_not eql(0)
        @vm.get_eetime.should >= @vm.get_estime
    end
    
    it "should resume an stopped VirtualMachine and check for the running VM" do
        @vm.resume.should eql(nil)
        @vm.deploy(@host.get_id).should eql(nil)
       
	@vm.check_state("runn", 80).should eql(true)
        @vm.check_active(100).should eql(true) 

        sleep 15
        
        @vm.get_reason.should eql(0)
        @vm.get_stime.should > 0
        @vm.get_etime.should eql(0)
        @vm.get_pstime.should > 0
        @vm.get_petime.should > 0
        @vm.get_rstime.should > 0
        @vm.get_retime.should eql(0)
        @vm.get_estime.should eql(0)
        @vm.get_eetime.should eql(0)
    end
    
    it "should shutdown the VM and check for the done state" do
        sleep 20
        @vm.shutdown.should eql(nil)
        
        @vm.check_state("done", 80)

        @vm.get_reason.should eql(0)
        @vm.get_stime.should > 0
        @vm.get_etime.should >= @vm.get_stime
        @vm.get_pstime.should_not eql(0)
        @vm.get_petime.should >= @vm.get_pstime
        @vm.get_rstime.should_not eql(0)
        @vm.get_retime.should >= @vm.get_rstime
        @vm.get_estime.should_not eql(0)
        @vm.get_eetime.should >= @vm.get_estime
    end
end
