#!/bin/bash

# --------------------------------------------------------------------------
# Copyright 2010, C12G Labs S.L.
#
# This file is part of OpenNebula VMware Drivers.
#
# OpenNebula VMware Drivers is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or the hope That it will be useful, but (at your
# option) any later version.
#
# OpenNebula VMware Drivers is distributed in WITHOUT ANY WARRANTY;
# without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License
# along with OpenNebula VMware Drivers . If not, see
# <http://www.gnu.org/licenses/>
# --------------------------------------------------------------------------

#-------------------------------------------------------------------------------
# Install program for OpenNebula VMWare Drivers Addon. It will be installed in 
# $ONE_LOCATION if defined, otherwise it'll be installed under /.
#
# To install in non-gcc platforms and to fine tune C flags, change the CC and CCFLAGS
#-------------------------------------------------------------------------------

CC="gcc"
CCFLAGS=

DIR=`dirname $0`

#-------------------------------------------------------------------------------
# Path location
#-------------------------------------------------------------------------------
if [ -n "$ONE_LOCATION" ]; then
    BIN_LOCATION="$ONE_LOCATION/bin"
    LIB_LOCATION="$ONE_LOCATION/lib"
    ETC_LOCATION="$ONE_LOCATION/etc"
    SHARE_LOCATION="$ONE_LOCATION/share"
else
    BIN_LOCATION="/usr/bin"
    LIB_LOCATION="/usr/lib/one"
    ETC_LOCATION="/etc/one"
    SHARE_LOCATION="/usr/share/one"
fi


#-------------------------------------------------------------------------------
# Compile the tty_expect utility
#-------------------------------------------------------------------------------
$CC $CCFLAGS -o $DIR/src/tty_expect/tty_expect $DIR/src/tty_expect/tty_expect.c -lutil || error=true 


# Make dirs and copy files

# tty_expect
cp $DIR/src/tty_expect/tty_expect $DESTDIR$BIN_LOCATION || error=true
chmod +x $DESTDIR$BIN_LOCATION/tty_expect

# bin
cp $DIR/lib/onevmware $DESTDIR$BIN_LOCATION || error=true

# lib
cp $DIR/lib/vmwarelib.rb $DESTDIR$LIB_LOCATION/ruby || error=true
cp $DIR/lib/ImageRepositoryVMware.rb $DESTDIR$LIB_LOCATION/ruby/OpenNebula || error=true
cp $DIR/share/vmwarerc $DESTDIR$ETC_LOCATION || error=true
cp -p $DIR/share/fix_owner_perms.sh $DESTDIR$SHARE_LOCATION/hooks || error=true

# vmm 
mkdir -p $DESTDIR$LIB_LOCATION/remotes/vmm/vmware || error=true
mkdir $DESTDIR$ETC_LOCATION/vmm_sh &> /dev/null
cp -r $DIR/vmm/remotes/* $DESTDIR$LIB_LOCATION/remotes/vmm/vmware || error=true
cp -r $DIR/vmm/etc/* $DESTDIR$ETC_LOCATION/vmm_sh || error=true

# im
mkdir -p $DESTDIR$LIB_LOCATION/remotes/im/vmware.d || error=true
cp -r $DIR/im/remotes/* $DESTDIR$LIB_LOCATION/remotes/im/vmware.d || error=true

# tm
mkdir $DESTDIR$ETC_LOCATION/tm_vmware &> /dev/null
mkdir $DESTDIR$LIB_LOCATION/tm_commands/vmware &> /dev/null
cp $DIR/tm/etc/tm_vmware.conf $DESTDIR$ETC_LOCATION/tm_vmware || error=true
cp $DIR/tm/commands/* $DESTDIR$LIB_LOCATION/tm_commands/vmware || error=true

# Make changes to image hook
LAST_HOOK_LINE=`tail -1 $DESTDIR$SHARE_LOCATION/hooks/image.rb`
LAST_ADDITION_LINE=`tail -1 $DIR/share/image.rb.addition`

if [ "x$LAST_HOOK_LINE" != "x$LAST_ADDITION_LINE" ]; then
    cat $DIR/share/image.rb.addition >> $DESTDIR$SHARE_LOCATION/hooks/image.rb || error=true
fi

# Report error or success
if [ -n "$error" ]; then
    echo "There was a problem with the installation"
else
    echo "VMWare Drivers Addon successfully installed"
    echo 
    cat $DIR/share/oned.conf.vmware.README
fi
