require ENV['ONE_SIMLOCATION']+'/lib/test_lib'
require 'open4'
require 'pp'

describe "Image Catalog Usage Integration tests" do
    before(:all) do

         @fixed_template = {:name => "fixednetwork",
                            :type => "FIXED",
                            :bridge => "VM Network",
                            :leases => [{:ip => "192.168.1.114"},
                                        {:ip => "192.168.1.115"}]
                            }


        fixed_text = TemplateParser::template_like_str(@fixed_template, true)
        @fixed_net = VirtualNetworkTest.new({:template_text => fixed_text})
        @fixed_net.create.should eql(nil)
        @fixed_net.info.should eql(nil)

        # Create Images Persistent & Non Persistent
        @nonpers_image_template = {:name => "nonpersimage"}
        @nonpers_image = ImageTest.new({:template => @nonpers_image_template})
        @nonpers_image.create_vmware.should eql(nil)
        @nonpers_image.info.should eql(nil)

        @pers_image_template = {:name => "persimage"}

        @pers_image = ImageTest.new({:template => @pers_image_template})
        @pers_image.create_vmware.should eql(nil)
        @pers_image.info.should eql(nil)
        @pers_image.persistent.should eql(nil)
        @pers_image.info.should eql(nil)
        @pers_image.get_persistent.should eql(1)

        # Create host
        @host = HostTest.new
        @host.create.should eql(nil)
        @host.info.should eql(nil)

        # Create VM with Nonpersistent disk and VM with Persistent disk
        @vm_nonpersdisk_template = {
            :cpu  => 1,
            :memory => 256,
            :disk => {
                :image_id => @nonpers_image.get_id
            },
            :nic => {
                :network => @fixed_template[:name]
            }
        }

        @vm_nonpersdisk = VirtualMachineTest.new({:template => @vm_nonpersdisk_template})
        @vm_nonpersdisk.submit.should eql(nil)

        host_id = @host.get_id
        @vm_nonpersdisk.deploy(host_id).should eql(nil)
        
        @vm_nonpersdisk.check_state("runn", 80).should eql(true)
        @vm_nonpersdisk.check_active(100).should eql(true)

        @vm_persdisk_template = {
            :cpu  => 1,
            :memory => 256,
            :disk => {
                :image_id => @pers_image.get_id
            },
            :nic => {
                :network => @fixed_template[:name]
            }
        }

        @vm_persdisk = VirtualMachineTest.new({:template => @vm_persdisk_template})

        @vm_persdisk.submit.should eql(nil)

        host_id = @host.get_id
        @vm_persdisk.deploy(host_id).should eql(nil)

        # Check VMs in running state
        @vm_persdisk.check_state("runn", 80).should eql(true)
        @vm_persdisk.check_active(100).should eql(true)
    end


    it "should have the correct save/clone tags" do
        @vm_nonpersdisk.info.should eql(nil)
        @vm_nonpersdisk.get_disk_clone(0).should eql("YES")
        @vm_nonpersdisk.get_disk_save(0).should eql("NO")

        @vm_persdisk.info.should eql(nil)
        @vm_persdisk.get_disk_clone(0).should eql("NO")
        @vm_persdisk.get_disk_save(0).should eql("YES")
    end


    it "should shutdown and have the right modification times" do
        sleep 20
        @vm_nonpersdisk.shutdown.should eql(nil)
        @vm_persdisk.shutdown.should eql(nil)

        @vm_nonpersdisk.check_state("done", 80).should eql(true)
        @vm_persdisk.check_state("done", 80).should eql(true)
        
        sleep 10

        nonpersdisk_modtime =
            File.mtime(@vm_nonpersdisk.get_disk_source(0))
        nonpersvm_rstime = @vm_nonpersdisk.get_rstime

        nonpersvm_rstime.to_i.should > nonpersdisk_modtime.to_i

        persvm_rstime = @vm_persdisk.get_rstime

        persdisk_modtime =
            File.mtime(@vm_persdisk.get_disk_source(0))

        persvm_rstime.to_i.should < persdisk_modtime.to_i

        @pers_image.get_state.should eql("rdy")
    end
end

