require ENV['ONE_SIMLOCATION']+'/lib/test_lib'
require 'open4'

describe "SaveAs Functionality Integration tests" do
    before(:all) do
         @fixed_template = {:name => "fixednetwork",
                            :type => "FIXED",
                            :bridge => "VM Network",
                            :leases => [{:ip => "192.168.1.116"},
                                        {:ip => "192.168.1.117"}]
                            }


        fixed_text = TemplateParser::template_like_str(@fixed_template, true)
        @fixed_net = VirtualNetworkTest.new({:template_text => fixed_text})
        @fixed_net.create.should eql(nil)
        @fixed_net.info.should eql(nil)
        
        # Create Image Persistent    
        @nonpers_image_template = {:name => "nonpersimage"}

        @nonpers_image = ImageTest.new({:template => @nonpers_image_template})

        @nonpers_image.create_vmware.should eql(nil)
        @nonpers_image.info.should eql(nil)
        @nonpers_image.get_persistent.should eql(0)
        
        # Create host    
        @host = HostTest.new
        @host.create.should eql(nil)
        @host.info.should eql(nil)
        
        # Create VM with Persistent disk                
        @vm_nonpersdisk_template = {
            :cpu  => 1,
            :memory => 256,
            :disk => {
                :image_id => @nonpers_image.get_id
            },
            :nic => {
                :network => @fixed_template[:name]
            }
        }
        
        @vm_nonpersdisk = VirtualMachineTest.new({:template => @vm_nonpersdisk_template})
        
        @vm_nonpersdisk.submit.should eql(nil)
        
        host_id = @host.get_id
        @vm_nonpersdisk.deploy(host_id).should eql(nil)
        
        # Check that the VM is running 
        @vm_nonpersdisk.check_state("runn", 80).should eql(true)
        @vm_nonpersdisk.check_active(100).should eql(true)  
    end
    
    
    it "should have the correct saveas in the vm template" do
        newimage_template = {:name => "imageforsaveas"}
                             
        newimage = ImageTest.new({:template => newimage_template})
        template_text = TemplateParser::template_like_str(newimage_template, true)
        newimage.allocate(template_text).should eql(nil)
        newimage.info.should eql(nil)
        
        @vm_nonpersdisk.get_disk_saveas(0).should eql(nil) 
        
        @vm_nonpersdisk.save_as(0,newimage.get_id).should eql(nil)
        @vm_nonpersdisk.info.should eql(nil)    
        
        @vm_nonpersdisk.info.should eql(nil)
        @vm_nonpersdisk.get_disk_clone(0).should eql("YES")
        @vm_nonpersdisk.get_disk_save(0).should eql("YES")
        @vm_nonpersdisk.get_disk_saveas(0).should eql(newimage.get_id.to_s)
    end
    
    
    it "should shutdown and have correct modification times of the saved images" do  
        sleep 40
        @vm_nonpersdisk.shutdown.should eql(nil)  
        
        @vm_nonpersdisk.check_state("done", 80).should eql(true)
        
        sleep 60
        
        savedas_image = ImageTest.new({:with_id => @vm_nonpersdisk.get_disk_saveas(0)})
        savedas_image.info.should eql(nil)

        savedas_image_path  = savedas_image.get_source
        original_image_path = @nonpers_image.get_source

        savedas_modtime     = File.mtime(savedas_image_path)
        original_modtime    = File.mtime(original_image_path)

        savedas_modtime.to_i.should > original_modtime.to_i
    end
end



